@@ -1,23 +1,24 @@
 import logging
+import re
 
 from typing import Text, List, Optional, Dict, Any
 
 from rasa.nlu.config import RasaNLUModelConfig
-from rasa.nlu.training_data import TrainingData, Message
+from rasa.shared.nlu.training_data.training_data import TrainingData
+from rasa.shared.nlu.training_data.message import Message
 from rasa.nlu.components import Component
-from rasa.nlu.constants import (
-    RESPONSE,
-    TEXT,
-    CLS_TOKEN,
-    TOKENS_NAMES,
-    MESSAGE_ATTRIBUTES,
+from rasa.nlu.constants import TOKENS_NAMES, MESSAGE_ATTRIBUTES
+from rasa.shared.nlu.constants import (
     INTENT,
+    INTENT_RESPONSE_KEY,
+    RESPONSE_IDENTIFIER_DELIMITER,
+    ACTION_NAME,
 )
 
 logger = logging.getLogger(__name__)
 
 
-class Token(object):
+class Token:
     def __init__(
         self,
         text: Text,
@@ -72,6 +73,11 @@ class Tokenizer(Component):
         )
         # split symbol for intents
         self.intent_split_symbol = self.component_config.get("intent_split_symbol", "_")
+        # token pattern to further split tokens
+        token_pattern = self.component_config.get("token_pattern", None)
+        self.token_pattern_regex = None
+        if token_pattern:
+            self.token_pattern_regex = re.compile(token_pattern)
 
     def tokenize(self, message: Message, attribute: Text) -> List[Token]:
         """Tokenizes the text of the provided attribute of the incoming message."""
@@ -88,23 +94,28 @@ class Tokenizer(Component):
 
         for example in training_data.training_examples:
             for attribute in MESSAGE_ATTRIBUTES:
-                if example.get(attribute) is not None:
-                    if attribute == INTENT:
-                        tokens = self._split_intent(example)
+                if (
+                    example.get(attribute) is not None
+                    and not example.get(attribute) == ""
+                ):
+                    if attribute in [INTENT, ACTION_NAME, INTENT_RESPONSE_KEY]:
+                        tokens = self._split_name(example, attribute)
                     else:
                         tokens = self.tokenize(example, attribute)
-                        tokens = self.add_cls_token(tokens, attribute)
                     example.set(TOKENS_NAMES[attribute], tokens)
 
     def process(self, message: Message, **kwargs: Any) -> None:
         """Tokenize the incoming message."""
+        for attribute in MESSAGE_ATTRIBUTES:
+            if isinstance(message.get(attribute), str):
+                if attribute in [INTENT, ACTION_NAME, RESPONSE_IDENTIFIER_DELIMITER]:
+                    tokens = self._split_name(message, attribute)
+                else:
+                    tokens = self.tokenize(message, attribute)
 
-        tokens = self.tokenize(message, TEXT)
-        tokens = self.add_cls_token(tokens, TEXT)
-        message.set(TOKENS_NAMES[TEXT], tokens)
+                message.set(TOKENS_NAMES[attribute], tokens)
 
-    def _split_intent(self, message: Message):
-        text = message.get(INTENT)
+    def _tokenize_on_split_symbol(self, text: Text) -> List[Text]:
 
         words = (
             text.split(self.intent_split_symbol)
@@ -112,8 +123,60 @@ class Tokenizer(Component):
             else [text]
         )
 
+        return words
+
+    def _split_name(self, message: Message, attribute: Text = INTENT) -> List[Token]:
+        text = message.get(attribute)
+
+        # for INTENT_RESPONSE_KEY attribute,
+        # first split by RESPONSE_IDENTIFIER_DELIMITER
+        if attribute == INTENT_RESPONSE_KEY:
+            intent, response_key = text.split(RESPONSE_IDENTIFIER_DELIMITER)
+            words = self._tokenize_on_split_symbol(
+                intent
+            ) + self._tokenize_on_split_symbol(response_key)
+
+        else:
+            words = self._tokenize_on_split_symbol(text)
+
         return self._convert_words_to_tokens(words, text)
 
+    def _apply_token_pattern(self, tokens: List[Token]) -> List[Token]:
+        """Apply the token pattern to the given tokens.
+
+        Args:
+            tokens: list of tokens to split
+
+        Returns:
+            List of tokens.
+        """
+        if not self.token_pattern_regex:
+            return tokens
+
+        final_tokens = []
+        for token in tokens:
+            new_tokens = self.token_pattern_regex.findall(token.text)
+            new_tokens = [t for t in new_tokens if t]
+
+            if not new_tokens:
+                final_tokens.append(token)
+
+            running_offset = 0
+            for new_token in new_tokens:
+                word_offset = token.text.index(new_token, running_offset)
+                word_len = len(new_token)
+                running_offset = word_offset + word_len
+                final_tokens.append(
+                    Token(
+                        new_token,
+                        token.start + word_offset,
+                        data=token.data,
+                        lemma=token.lemma,
+                    )
+                )
+
+        return final_tokens
+
     @staticmethod
     def _convert_words_to_tokens(words: List[Text], text: Text) -> List[Token]:
         running_offset = 0
@@ -126,12 +189,3 @@ class Tokenizer(Component):
             tokens.append(Token(word, word_offset))
 
         return tokens
-
-    @staticmethod
-    def add_cls_token(tokens: List[Token], attribute: Text) -> List[Token]:
-        if attribute in [RESPONSE, TEXT] and tokens:
-            # +1 to have a space between the last token and the __cls__ token
-            idx = tokens[-1].end + 1
-            tokens.append(Token(CLS_TOKEN, idx))
-
-        return tokens
